Documentation
¶
Index ¶
- Constants
- func AddAddClusterAdminCmd(parent *cobra.Command, opts *util.GlobalOptions)
- func AddArgoCDCmd(parentCmd *cobra.Command, opts *util.GlobalOptions)
- func AddBetaCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
- func AddBetaInstallCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
- func AddBetaVaultSecretCmd(parentCmd *cobra.Command, opts *util.GlobalOptions)
- func AddBootstrapGcpCleanupCmd(bootstrapGcp *cobra.Command, opts *util.GlobalOptions)
- func AddBootstrapGcpCmd(parent *cobra.Command, opts *util.GlobalOptions)
- func AddBootstrapGcpPostconfigCmd(bootstrapGcp *cobra.Command, opts *util.GlobalOptions)
- func AddBootstrapGcpRestartVMsCmd(bootstrapGcp *cobra.Command, opts *util.GlobalOptions)
- func AddBootstrapLocalCmd(parent *cobra.Command)
- func AddBuildCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
- func AddBuildImageCmd(parentCmd *cobra.Command, opts *util.GlobalOptions)
- func AddBuildImagesCmd(build *cobra.Command, opts *util.GlobalOptions)
- func AddCreateCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
- func AddCreateTestUserCmd(parent *cobra.Command, opts *util.GlobalOptions)
- func AddDownloadCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
- func AddDownloadPackageCmd(download *cobra.Command, opts *util.GlobalOptions)
- func AddExtendBaseimageCmd(extend *cobra.Command, opts *util.GlobalOptions)
- func AddExtendCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
- func AddInitCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
- func AddInitInstallConfigCmd(init *cobra.Command, opts *util.GlobalOptions)
- func AddInstallCephCmd(install *cobra.Command)
- func AddInstallCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
- func AddInstallOpenBaoCmd(install *cobra.Command, opts *util.GlobalOptions)
- func AddLicensesCmd(rootCmd *cobra.Command)
- func AddListAPIKeysCmd(list *cobra.Command, opts *util.GlobalOptions)
- func AddListCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
- func AddListPackagesCmd(list *cobra.Command, opts *util.GlobalOptions)
- func AddOmsUpdateCmd(parentCmd *cobra.Command)
- func AddPCAppsCmd(parentCmd *cobra.Command, opts *util.GlobalOptions)
- func AddRevokeCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
- func AddSmoketestCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
- func AddTemplateCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
- func AddTemplateConfigCmd(parentCmd *cobra.Command, opts *util.GlobalOptions)
- func AddUpdateCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
- func AddUpdateDockerfileCmd(parentCmd *cobra.Command, opts *util.GlobalOptions)
- func AddUpdateInstallConfigCmd(update *cobra.Command, opts *util.GlobalOptions)
- func AddUpgradeCephCmd(upgrade *cobra.Command)
- func AddUpgradeCmd(rootCmd *cobra.Command)
- func AddUpgradeCodesphereCmd(upgrade *cobra.Command)
- func AddVersionCmd(rootCmd *cobra.Command)
- func Execute()
- func GetRootCmd() *cobra.Command
- type AddClusterAdminCmd
- type AddClusterAdminOpts
- type BetaCmd
- type BetaInstallCmd
- type BetaVaultSecretCmd
- type BetaVaultSecretOpts
- type BootstrapGcpCleanupCmd
- type BootstrapGcpCleanupOpts
- type BootstrapGcpCmd
- type BootstrapGcpPostconfigCmd
- type BootstrapGcpPostconfigOpts
- type BootstrapGcpRestartVMsCmd
- type BootstrapGcpRestartVMsOpts
- type BootstrapLocalCmd
- func (c *BootstrapLocalCmd) BootstrapLocal() error
- func (c *BootstrapLocalCmd) ConfirmLocalBootstrapWarning() error
- func (c *BootstrapLocalCmd) GetKubeClient(ctx context.Context) (ctrlclient.Client, *rest.Config, error)
- func (c *BootstrapLocalCmd) RunE(_ *cobra.Command, args []string) error
- func (c *BootstrapLocalCmd) ValidateEncryptionTools() error
- func (c *BootstrapLocalCmd) ValidateHelmVersion(ctx context.Context) error
- func (c *BootstrapLocalCmd) ValidateKubernetesCluster(ctx context.Context) error
- func (c *BootstrapLocalCmd) ValidatePrerequisites(ctx context.Context) error
- type BuildCmd
- type BuildImageCmd
- type BuildImageOpts
- type BuildImagesCmd
- type BuildImagesOpts
- type CreateCmd
- type CreateTestUserCmd
- type CreateTestUserOpts
- type DownloadCmd
- type DownloadPackageCmd
- type DownloadPackageOpts
- type ExtendBaseimageCmd
- type ExtendBaseimageOpts
- type ExtendCmd
- type InitCmd
- type InitInstallConfigCmd
- type InitInstallConfigOpts
- type InstallArgoCDCmd
- type InstallArgoCDOpts
- type InstallCephCmd
- type InstallCmd
- type InstallOpenBaoCmd
- type InstallOpenBaoOpts
- type InstallPCAppsCmd
- type InstallPCAppsOpts
- type LicensesCmd
- type ListAPIKeysCmd
- type ListBuildsCmd
- type ListBuildsOpts
- type ListCmd
- type OMSSelfUpdater
- type OMSUpdater
- type RevokeCmd
- type SecretDependencyTracker
- func (t *SecretDependencyTracker) ACMEConfigChanged() bool
- func (t *SecretDependencyTracker) HasChanges() bool
- func (t *SecretDependencyTracker) MarkACMEConfigChanged()
- func (t *SecretDependencyTracker) MarkPostgresPrimaryCertNeedsRegen()
- func (t *SecretDependencyTracker) MarkPostgresReplicaCertNeedsRegen()
- func (t *SecretDependencyTracker) NeedsPostgresPrimaryCertRegen() bool
- func (t *SecretDependencyTracker) NeedsPostgresReplicaCertRegen() bool
- type SmoketestCmd
- type TemplateCmd
- type TemplateConfigCmd
- type TemplateConfigOpts
- type UpdateCmd
- type UpdateDockerfileCmd
- type UpdateDockerfileOpts
- type UpdateInstallConfigCmd
- type UpdateInstallConfigOpts
- type UpdateOmsCmd
- type UpgradeCephCmd
- type UpgradeCmd
- type UpgradeCodesphereCmd
- type VersionCmd
Constants ¶
const GitHubRepo = "codesphere-cloud/oms"
Variables ¶
This section is empty.
Functions ¶
func AddAddClusterAdminCmd ¶ added in v1.224.0
func AddAddClusterAdminCmd(parent *cobra.Command, opts *util.GlobalOptions)
func AddArgoCDCmd ¶ added in v1.14.0
func AddArgoCDCmd(parentCmd *cobra.Command, opts *util.GlobalOptions)
func AddBetaCmd ¶ added in v0.10.0
func AddBetaCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
func AddBetaInstallCmd ¶ added in v1.14.0
func AddBetaInstallCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
func AddBetaVaultSecretCmd ¶ added in v1.163.0
func AddBetaVaultSecretCmd(parentCmd *cobra.Command, opts *util.GlobalOptions)
func AddBootstrapGcpCleanupCmd ¶ added in v1.16.0
func AddBootstrapGcpCleanupCmd(bootstrapGcp *cobra.Command, opts *util.GlobalOptions)
func AddBootstrapGcpCmd ¶ added in v0.24.0
func AddBootstrapGcpCmd(parent *cobra.Command, opts *util.GlobalOptions)
func AddBootstrapGcpPostconfigCmd ¶ added in v0.32.1
func AddBootstrapGcpPostconfigCmd(bootstrapGcp *cobra.Command, opts *util.GlobalOptions)
func AddBootstrapGcpRestartVMsCmd ¶ added in v1.61.0
func AddBootstrapGcpRestartVMsCmd(bootstrapGcp *cobra.Command, opts *util.GlobalOptions)
func AddBootstrapLocalCmd ¶ added in v1.34.0
func AddBuildCmd ¶ added in v0.15.0
func AddBuildCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
func AddBuildImageCmd ¶ added in v0.15.0
func AddBuildImageCmd(parentCmd *cobra.Command, opts *util.GlobalOptions)
func AddBuildImagesCmd ¶ added in v0.15.0
func AddBuildImagesCmd(build *cobra.Command, opts *util.GlobalOptions)
func AddCreateCmd ¶ added in v1.104.0
func AddCreateCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
func AddCreateTestUserCmd ¶ added in v1.104.0
func AddCreateTestUserCmd(parent *cobra.Command, opts *util.GlobalOptions)
func AddDownloadCmd ¶
func AddDownloadCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
func AddDownloadPackageCmd ¶
func AddDownloadPackageCmd(download *cobra.Command, opts *util.GlobalOptions)
func AddExtendBaseimageCmd ¶ added in v0.10.0
func AddExtendBaseimageCmd(extend *cobra.Command, opts *util.GlobalOptions)
func AddExtendCmd ¶ added in v0.10.0
func AddExtendCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
func AddInitCmd ¶ added in v0.17.0
func AddInitCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
func AddInitInstallConfigCmd ¶ added in v0.17.0
func AddInitInstallConfigCmd(init *cobra.Command, opts *util.GlobalOptions)
func AddInstallCephCmd ¶
func AddInstallCmd ¶
func AddInstallCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
func AddInstallOpenBaoCmd ¶ added in v1.154.0
func AddInstallOpenBaoCmd(install *cobra.Command, opts *util.GlobalOptions)
AddInstallOpenBaoCmd registers the openbao subcommand under install.
func AddLicensesCmd ¶ added in v0.14.0
func AddListAPIKeysCmd ¶ added in v0.11.0
func AddListAPIKeysCmd(list *cobra.Command, opts *util.GlobalOptions)
func AddListCmd ¶
func AddListCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
func AddListPackagesCmd ¶
func AddListPackagesCmd(list *cobra.Command, opts *util.GlobalOptions)
func AddOmsUpdateCmd ¶ added in v0.12.0
func AddPCAppsCmd ¶ added in v1.175.0
func AddPCAppsCmd(parentCmd *cobra.Command, opts *util.GlobalOptions)
func AddRevokeCmd ¶
func AddRevokeCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
func AddSmoketestCmd ¶ added in v0.38.0
func AddSmoketestCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
func AddTemplateCmd ¶ added in v1.178.0
func AddTemplateCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
func AddTemplateConfigCmd ¶ added in v1.178.0
func AddTemplateConfigCmd(parentCmd *cobra.Command, opts *util.GlobalOptions)
func AddUpdateCmd ¶
func AddUpdateCmd(rootCmd *cobra.Command, opts *util.GlobalOptions)
func AddUpdateDockerfileCmd ¶ added in v0.15.0
func AddUpdateDockerfileCmd(parentCmd *cobra.Command, opts *util.GlobalOptions)
func AddUpdateInstallConfigCmd ¶ added in v0.21.0
func AddUpdateInstallConfigCmd(update *cobra.Command, opts *util.GlobalOptions)
func AddUpgradeCephCmd ¶
func AddUpgradeCmd ¶
func AddUpgradeCodesphereCmd ¶
func AddVersionCmd ¶
func Execute ¶
func Execute()
Execute executes the root command. This is called by main.main(). It only needs to happen once to the rootCmd.
func GetRootCmd ¶
GetRootCmd adds all child commands to the root command and sets flags appropriately.
Types ¶
type AddClusterAdminCmd ¶ added in v1.224.0
type AddClusterAdminCmd struct {
Opts AddClusterAdminOpts
// contains filtered or unexported fields
}
type AddClusterAdminOpts ¶ added in v1.224.0
type AddClusterAdminOpts struct {
*util.GlobalOptions
clusteradmin.Opts
}
type BetaInstallCmd ¶ added in v1.14.0
type BetaInstallCmd struct {
// contains filtered or unexported fields
}
BetaInstallCmd represents the install command
type BetaVaultSecretCmd ¶ added in v1.163.0
type BetaVaultSecretCmd struct {
Opts BetaVaultSecretOpts
// contains filtered or unexported fields
}
type BetaVaultSecretOpts ¶ added in v1.163.0
type BootstrapGcpCleanupCmd ¶ added in v1.16.0
type BootstrapGcpCleanupCmd struct {
Opts *BootstrapGcpCleanupOpts
// contains filtered or unexported fields
}
func (*BootstrapGcpCleanupCmd) ExecuteCleanup ¶ added in v1.16.0
func (c *BootstrapGcpCleanupCmd) ExecuteCleanup(deps *gcp.CleanupDeps) error
ExecuteCleanup performs the cleanup operation with the provided dependencies.
type BootstrapGcpCleanupOpts ¶ added in v1.16.0
type BootstrapGcpCmd ¶ added in v0.24.0
type BootstrapGcpCmd struct {
Opts *util.GlobalOptions
Env env.Env
CodesphereEnv *gcp.CodesphereEnvironment
InputRegistryType string
SSHQuiet bool
// contains filtered or unexported fields
}
func (*BootstrapGcpCmd) BootstrapGcp ¶ added in v0.24.0
func (c *BootstrapGcpCmd) BootstrapGcp() error
type BootstrapGcpPostconfigCmd ¶ added in v0.32.1
type BootstrapGcpPostconfigCmd struct {
Opts *BootstrapGcpPostconfigOpts
CodesphereEnv gcp.CodesphereEnvironment
// contains filtered or unexported fields
}
type BootstrapGcpPostconfigOpts ¶ added in v0.32.1
type BootstrapGcpPostconfigOpts struct {
*util.GlobalOptions
InstallConfigPath string
PrivateKeyPath string
}
type BootstrapGcpRestartVMsCmd ¶ added in v1.61.0
type BootstrapGcpRestartVMsCmd struct {
Opts *BootstrapGcpRestartVMsOpts
// contains filtered or unexported fields
}
type BootstrapGcpRestartVMsOpts ¶ added in v1.61.0
type BootstrapGcpRestartVMsOpts struct {
*util.GlobalOptions
ProjectID string
Zone string
Name string
}
type BootstrapLocalCmd ¶ added in v1.34.0
type BootstrapLocalCmd struct {
CodesphereEnv *local.CodesphereEnvironment
Yes bool
// contains filtered or unexported fields
}
func (*BootstrapLocalCmd) BootstrapLocal ¶ added in v1.34.0
func (c *BootstrapLocalCmd) BootstrapLocal() error
func (*BootstrapLocalCmd) ConfirmLocalBootstrapWarning ¶ added in v1.34.0
func (c *BootstrapLocalCmd) ConfirmLocalBootstrapWarning() error
func (*BootstrapLocalCmd) GetKubeClient ¶ added in v1.34.0
func (c *BootstrapLocalCmd) GetKubeClient(ctx context.Context) (ctrlclient.Client, *rest.Config, error)
func (*BootstrapLocalCmd) RunE ¶ added in v1.34.0
func (c *BootstrapLocalCmd) RunE(_ *cobra.Command, args []string) error
func (*BootstrapLocalCmd) ValidateEncryptionTools ¶ added in v1.34.0
func (c *BootstrapLocalCmd) ValidateEncryptionTools() error
func (*BootstrapLocalCmd) ValidateHelmVersion ¶ added in v1.34.0
func (c *BootstrapLocalCmd) ValidateHelmVersion(ctx context.Context) error
func (*BootstrapLocalCmd) ValidateKubernetesCluster ¶ added in v1.34.0
func (c *BootstrapLocalCmd) ValidateKubernetesCluster(ctx context.Context) error
func (*BootstrapLocalCmd) ValidatePrerequisites ¶ added in v1.34.0
func (c *BootstrapLocalCmd) ValidatePrerequisites(ctx context.Context) error
type BuildCmd ¶ added in v0.15.0
type BuildCmd struct {
// contains filtered or unexported fields
}
BuildCmd represents the build command
type BuildImageCmd ¶ added in v0.15.0
type BuildImageCmd struct {
Opts BuildImageOpts
Env env.Env
// contains filtered or unexported fields
}
BuildImageCmd represents the build image command
func (*BuildImageCmd) BuildImage ¶ added in v0.15.0
func (c *BuildImageCmd) BuildImage(pm installer.PackageManager, im system.ImageManager) error
AddBuildImageCmd adds the build image command to the parent command
type BuildImageOpts ¶ added in v0.15.0
type BuildImagesCmd ¶ added in v0.15.0
type BuildImagesCmd struct {
Opts *BuildImagesOpts
Env env.Env
// contains filtered or unexported fields
}
BuildImagesCmd represents the build images command
func (*BuildImagesCmd) BuildAndPushImages ¶ added in v0.15.0
func (c *BuildImagesCmd) BuildAndPushImages(pm installer.PackageManager, cm installer.ConfigManager, im system.ImageManager) error
type BuildImagesOpts ¶ added in v0.15.0
type BuildImagesOpts struct {
*util.GlobalOptions
Config string
Force bool
}
type CreateCmd ¶ added in v1.104.0
type CreateCmd struct {
// contains filtered or unexported fields
}
CreateCmd represents the create command group
type CreateTestUserCmd ¶ added in v1.104.0
type CreateTestUserCmd struct {
Opts CreateTestUserOpts
Env env.Env
// contains filtered or unexported fields
}
type CreateTestUserOpts ¶ added in v1.104.0
type CreateTestUserOpts struct {
*util.GlobalOptions
testuser.CreateTestUserOpts
}
type DownloadCmd ¶
type DownloadCmd struct {
// contains filtered or unexported fields
}
DownloadCmd represents the download command
type DownloadPackageCmd ¶
type DownloadPackageCmd struct {
Opts DownloadPackageOpts
FileWriter intutil.FileIO
// contains filtered or unexported fields
}
DownloadPackageCmd represents the package command
func (*DownloadPackageCmd) DownloadBuild ¶
type DownloadPackageOpts ¶
type ExtendBaseimageCmd ¶ added in v0.10.0
type ExtendBaseimageCmd struct {
Opts *ExtendBaseimageOpts
Env env.Env
// contains filtered or unexported fields
}
ExtendBaseimageCmd represents the baseimage command
func (*ExtendBaseimageCmd) ExtendBaseimage ¶ added in v0.10.0
func (c *ExtendBaseimageCmd) ExtendBaseimage(pm installer.PackageManager, im system.ImageManager) error
type ExtendBaseimageOpts ¶ added in v0.10.0
type ExtendCmd ¶ added in v0.10.0
type ExtendCmd struct {
// contains filtered or unexported fields
}
ExtendCmd represents the extend command
type InitInstallConfigCmd ¶ added in v0.17.0
type InitInstallConfigCmd struct {
Opts *InitInstallConfigOpts
FileWriter intutil.FileIO
// contains filtered or unexported fields
}
func (*InitInstallConfigCmd) InitInstallConfig ¶ added in v0.17.0
func (c *InitInstallConfigCmd) InitInstallConfig(icg installer.InstallConfigManager) error
type InitInstallConfigOpts ¶ added in v0.17.0
type InitInstallConfigOpts struct {
*util.GlobalOptions
ConfigFile string
VaultFile string
Profile string
AnsibleInventoryFile string
ValidateOnly bool
WithComments bool
Interactive bool
GenerateKeys bool
SecretsBaseDir string
DatacenterID int
DatacenterName string
DatacenterCity string
DatacenterCountryCode string
RegistryServer string
RegistryReplaceImagesInBom bool
RegistryLoadContainerImages bool
PostgresMode string
PostgresPrimaryIP string
PostgresPrimaryHostname string
PostgresReplicaIP string
PostgresReplicaName string
PostgresServerAddress string
CephCsiKubeletDir string
CephNodesSubnet string
CephHosts []files.CephHostConfig
KubernetesManagedByCodesphere bool
KubernetesAPIServerHost string
KubernetesControlPlanes []string
KubernetesWorkers []string
KubernetesPodCIDR string
KubernetesServiceCIDR string
ClusterGatewayServiceType string
ClusterGatewayIPAddresses []string
ClusterPublicGatewayServiceType string
ClusterPublicGatewayIPAddresses []string
MetalLBEnabled bool
MetalLBPools []files.MetalLBPool
ACMEEnabled bool
ACMEIssuerName string
ACMEEmail string
ACMEServer string
ACMEEABKeyID string
ACMEEABMacKey string
ACMEDNS01Provider string
CodesphereDomain string
CodespherePublicIP string
CodesphereWorkspaceHostingBaseDomain string
CodesphereCustomDomainsCNameBaseDomain string
CodesphereDNSServers []string
CodesphereWorkspaceImageBomRef string
CodesphereHostingPlanCPUTenth int
CodesphereHostingPlanMemoryMb int
CodesphereHostingPlanStorageMb int
CodesphereHostingPlanTempStorageMb int
CodesphereWorkspacePlanName string
CodesphereWorkspacePlanMaxReplicas int
CodesphereOpenBaoUri string
CodesphereOpenBaoEngine string
CodesphereOpenBaoUser string
CodesphereOpenBaoPassword string
}
type InstallArgoCDCmd ¶ added in v1.14.0
type InstallArgoCDCmd struct {
Opts InstallArgoCDOpts
// contains filtered or unexported fields
}
InstallArgoCDCmd represents the argocd command
type InstallArgoCDOpts ¶ added in v1.14.0
type InstallCephCmd ¶
type InstallCephCmd struct {
// contains filtered or unexported fields
}
InstallCephCmd represents the ceph command
type InstallCmd ¶
type InstallCmd struct {
// contains filtered or unexported fields
}
InstallCmd represents the install command
type InstallOpenBaoCmd ¶ added in v1.154.0
type InstallOpenBaoCmd struct {
Opts *InstallOpenBaoOpts
// contains filtered or unexported fields
}
InstallOpenBaoCmd wraps the cobra command and options for 'oms install openbao'.
type InstallOpenBaoOpts ¶ added in v1.154.0
type InstallOpenBaoOpts struct {
*util.GlobalOptions
Namespace string
SecretsEngineName string
BaoUsername string
DRBackupPath string
Replicas int
StorageSize string
Timeout time.Duration
AgeKeyFile string
Yes bool
}
InstallOpenBaoOpts holds the CLI flags for the OpenBao installer.
type InstallPCAppsCmd ¶ added in v1.175.0
type InstallPCAppsCmd struct {
Opts InstallPCAppsOpts
// contains filtered or unexported fields
}
InstallPCAppsCmd represents the pc-apps command
type InstallPCAppsOpts ¶ added in v1.175.0
type LicensesCmd ¶ added in v0.14.0
type LicensesCmd struct {
// contains filtered or unexported fields
}
type ListAPIKeysCmd ¶ added in v0.11.0
type ListAPIKeysCmd struct {
TableWriter intutil.TableWriter
// contains filtered or unexported fields
}
func (*ListAPIKeysCmd) PrintKeysTable ¶ added in v0.11.0
func (c *ListAPIKeysCmd) PrintKeysTable(keys []portal.ApiKey)
type ListBuildsCmd ¶
type ListBuildsCmd struct {
Opts ListBuildsOpts
TableWriter intutil.TableWriter
// contains filtered or unexported fields
}
func (*ListBuildsCmd) PrintPackagesTable ¶
func (c *ListBuildsCmd) PrintPackagesTable(packages portal.Builds)
type ListBuildsOpts ¶
type ListBuildsOpts struct {
*util.GlobalOptions
Internal bool
Sort string
}
type OMSSelfUpdater ¶ added in v0.12.0
type OMSSelfUpdater struct{}
func (*OMSSelfUpdater) Update ¶ added in v0.13.0
func (s *OMSSelfUpdater) Update(ctx context.Context, current string, repo selfupdate.Repository) (string, string, error)
type OMSUpdater ¶ added in v0.12.0
type OMSUpdater interface {
Update(ctx context.Context, current string, repo selfupdate.Repository) (string, string, error)
}
type SecretDependencyTracker ¶ added in v0.21.0
type SecretDependencyTracker struct {
// contains filtered or unexported fields
}
func NewSecretDependencyTracker ¶ added in v0.21.0
func NewSecretDependencyTracker() *SecretDependencyTracker
func (*SecretDependencyTracker) ACMEConfigChanged ¶ added in v0.36.0
func (t *SecretDependencyTracker) ACMEConfigChanged() bool
func (*SecretDependencyTracker) HasChanges ¶ added in v0.21.0
func (t *SecretDependencyTracker) HasChanges() bool
func (*SecretDependencyTracker) MarkACMEConfigChanged ¶ added in v0.36.0
func (t *SecretDependencyTracker) MarkACMEConfigChanged()
func (*SecretDependencyTracker) MarkPostgresPrimaryCertNeedsRegen ¶ added in v0.21.0
func (t *SecretDependencyTracker) MarkPostgresPrimaryCertNeedsRegen()
func (*SecretDependencyTracker) MarkPostgresReplicaCertNeedsRegen ¶ added in v0.21.0
func (t *SecretDependencyTracker) MarkPostgresReplicaCertNeedsRegen()
func (*SecretDependencyTracker) NeedsPostgresPrimaryCertRegen ¶ added in v0.21.0
func (t *SecretDependencyTracker) NeedsPostgresPrimaryCertRegen() bool
func (*SecretDependencyTracker) NeedsPostgresReplicaCertRegen ¶ added in v0.21.0
func (t *SecretDependencyTracker) NeedsPostgresReplicaCertRegen() bool
type SmoketestCmd ¶ added in v0.38.0
type SmoketestCmd struct {
// contains filtered or unexported fields
}
SmoketestCmd represents the smoketest command
type TemplateCmd ¶ added in v1.178.0
type TemplateCmd struct {
// contains filtered or unexported fields
}
type TemplateConfigCmd ¶ added in v1.178.0
type TemplateConfigCmd struct {
Opts TemplateConfigOpts
// contains filtered or unexported fields
}
func (*TemplateConfigCmd) Render ¶ added in v1.178.0
func (c *TemplateConfigCmd) Render() ([]byte, error)
type TemplateConfigOpts ¶ added in v1.178.0
type TemplateConfigOpts struct {
*util.GlobalOptions
Config string
Vault string
AgeKey string
}
type UpdateDockerfileCmd ¶ added in v0.15.0
type UpdateDockerfileCmd struct {
Opts UpdateDockerfileOpts
Env env.Env
// contains filtered or unexported fields
}
func (*UpdateDockerfileCmd) RunE ¶ added in v0.15.0
func (c *UpdateDockerfileCmd) RunE(_ *cobra.Command, args []string) error
func (*UpdateDockerfileCmd) UpdateDockerfile ¶ added in v0.15.0
func (c *UpdateDockerfileCmd) UpdateDockerfile(pm installer.PackageManager, im system.ImageManager, args []string) error
type UpdateDockerfileOpts ¶ added in v0.15.0
type UpdateInstallConfigCmd ¶ added in v0.21.0
type UpdateInstallConfigCmd struct {
Opts *UpdateInstallConfigOpts
FileWriter intutil.FileIO
// contains filtered or unexported fields
}
func (*UpdateInstallConfigCmd) RunE ¶ added in v0.21.0
func (c *UpdateInstallConfigCmd) RunE(_ *cobra.Command, args []string) error
func (*UpdateInstallConfigCmd) UpdateInstallConfig ¶ added in v0.21.0
func (c *UpdateInstallConfigCmd) UpdateInstallConfig(icg installer.InstallConfigManager) error
type UpdateInstallConfigOpts ¶ added in v0.21.0
type UpdateInstallConfigOpts struct {
*util.GlobalOptions
ConfigFile string
VaultFile string
WithComments bool
// Fields that can be updated
PostgresPrimaryIP string
PostgresPrimaryHostname string
PostgresReplicaIP string
PostgresReplicaName string
PostgresServerAddress string
CephNodesSubnet string
KubernetesAPIServerHost string
KubernetesPodCIDR string
KubernetesServiceCIDR string
ClusterGatewayServiceType string
ClusterGatewayIPAddresses []string
ClusterPublicGatewayServiceType string
ClusterPublicGatewayIPAddresses []string
ACMEEnabled bool
ACMEIssuerName string
ACMEEmail string
ACMEServer string
ACMEEABKeyID string
ACMEEABMacKey string
ACMEDNS01Provider string
CodesphereDomain string
CodespherePublicIP string
CodesphereWorkspaceHostingBaseDomain string
CodesphereCustomDomainsCNameBaseDomain string
CodesphereDNSServers []string
}
type UpdateOmsCmd ¶ added in v0.12.0
type UpdateOmsCmd struct {
Version version.Version
Updater OMSUpdater
}
func (*UpdateOmsCmd) SelfUpdate ¶ added in v0.12.0
func (c *UpdateOmsCmd) SelfUpdate() error
type UpgradeCephCmd ¶
type UpgradeCephCmd struct {
// contains filtered or unexported fields
}
UpgradeCephCmd represents the ceph command
type UpgradeCmd ¶
type UpgradeCmd struct {
// contains filtered or unexported fields
}
UpgradeCmd represents the upgrade command
type UpgradeCodesphereCmd ¶
type UpgradeCodesphereCmd struct {
// contains filtered or unexported fields
}
UpgradeCodesphereCmd represents the codesphere command
type VersionCmd ¶
type VersionCmd struct {
// contains filtered or unexported fields
}
Source Files
¶
- add_cluster_admin.go
- argocd.go
- beta.go
- beta_install.go
- beta_vault_secret.go
- bootstrap_gcp.go
- bootstrap_gcp_cleanup.go
- bootstrap_gcp_postconfig.go
- bootstrap_gcp_restart_vms.go
- bootstrap_local.go
- build.go
- build_image.go
- build_images.go
- create.go
- create_test_user.go
- download.go
- download_package.go
- extend.go
- extend_baseimage.go
- init.go
- init_install_config.go
- install.go
- install_ceph.go
- install_openbao.go
- licenses.go
- list.go
- list_api_keys.go
- list_packages.go
- pc_apps.go
- revoke.go
- root.go
- smoketest.go
- template.go
- template_config.go
- update.go
- update_dockerfile.go
- update_install_config.go
- update_oms.go
- upgrade.go
- upgrade_ceph.go
- upgrade_codesphere.go
- version.go